==> sfp-plus-i2c-v0.3.tar.gz: sfp-plus-i2c-v0.3/sw/jsfp/src/nl/nikhef/sfp/MultiSFPProvider.java <==
/* *****************************************************************************
 * SaFariPark SFP+ editor and support libraries
 * Copyright (C) 2017 National Institute for Subatomic Physics Nikhef
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/
package nl.nikhef.sfp;

import java.io.IOException;
import java.util.List;

import com.ftdi.DeviceType;
import com.ftdi.FTDevice;

public class MultiSFPProvider extends SFPProviderBase
{
	
	@Override
	public String getName() {
		return "MultiSFP";
	}

	public SFPDevice getDeviceBySerial(String serial) {
		for (SFPDevice dev : getDevices()) {
			if (dev.getSerial().equals(serial)) return dev;
		}
		return null;
	}
	

	public void scanForNewDevices() {
		try {
			List<FTDevice> devs;
			synchronized(this)
			{
				
				devs = FTDevice.getDevices(true);
				// System.out.printf("FTDevice.getDevices() Found %d devices\n", devs.size());
			}
			
			for (FTDevice devRaw : devs)
			{
				if (devRaw.getDevType() == DeviceType.DEVICE_2232H && devRaw.getDevDescription().equals("MultiSFP A")) {
					
					// Only get the primary 'A' device, we know the second.
					String serial = devRaw.getDevSerialNumber();
					
					// chop of the last part from the serial:
					serial = serial.substring(0, serial.length() - 1);
					
					SFPDevice dev = getDeviceBySerial(serial);
					
					
					if (dev == null) 
					{
						dev = new MultiSFPDevice(serial, this);
					}
					updAdd(dev);
				}
			}
			
		} catch (IOException e) {
			e.printStackTrace();
		}
		updProcess();		
	}
	
	

}

==> sfp-plus-i2c-v0.4.tar.gz: sfp-plus-i2c-v0.4/sw/jsfp/src/nl/nikhef/sfp/MultiSFPProvider.java <==
/* *****************************************************************************
 * SaFariPark SFP+ editor and support libraries
 * Copyright (C) 2017 National Institute for Subatomic Physics Nikhef
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/
package nl.nikhef.sfp;

import java.io.IOException;
import java.util.List;

import com.ftdi.DeviceType;
import com.ftdi.FTDevice;

public class MultiSFPProvider extends SFPProviderBase
{
	
	@Override
	public String getName() {
		return "MultiSFP";
	}

	public SFPDevice getDeviceBySerial(String serial) {
		for (SFPDevice dev : getDevices()) {
			if (dev.getSerial().equals(serial)) return dev;
		}
		return null;
	}
	

	public void scanForNewDevices() {
		try {
			List<FTDevice> devs;
			synchronized(this)
			{
				
				devs = FTDevice.getDevices(true);
			}
			
			for (FTDevice devRaw : devs)
			{
				
				// System.out.println("Device: " + devRaw);

				// XXX On Linux the MultiSFP A is descriptor is not generated once opened. But B remains. So we sync on that.
				//
				if (devRaw.getDevType() == DeviceType.DEVICE_2232H && devRaw.getDevDescription().equals("MultiSFP B")) {
					
					// Only get the primary 'A' device, we know the second.
					String serial = devRaw.getDevSerialNumber();
					
					// chop of the last part from the serial:
					serial = serial.substring(0, serial.length() - 1);
					
					SFPDevice dev = getDeviceBySerial(serial);
					
					
					if (dev == null) 
					{
						dev = new MultiSFPDevice(serial, this);
					}
					updAdd(dev);
				}
			}
			
		} catch (IOException e) {
			e.printStackTrace();
		}
		updProcess();		
	}
	
	

}
